@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _CONSTANTMANAGER_
 #define _CONSTANTMANAGER_
@@ -42,6 +40,8 @@ public:
   int getConstant(wstring const &constant);
   void write(FILE *output);
   void read(FILE *input);
+  void serialise(std::ostream &serialised) const;
+  void deserialise(std::istream &serialised);
 };
 
 #endif
